DialogDecoration class

Constructors

DialogDecoration({EdgeInsets? padding, BoxBorder? thumbBorder, TextStyle? headerStyle, TextStyle? contentStyle, double? iconSize, ShapeBorder? shape, double? elevation, BorderRadius? thumbBorderRadius, TextAlign? textAlign, BorderRadius? buttonBorderRadius, double? buttonElevation, TextStyle? buttonTextStyle, Color? buttonForegroundTextColor, EdgeInsets? buttonPadding, double? secondaryButtonBorderWidth})
DialogDecoration.defaultValue()
factory

Properties

buttonBorderRadius BorderRadius?
final
buttonElevation double?
final
buttonForegroundTextColor Color?
final
buttonPadding EdgeInsets?
final
buttonTextStyle TextStyle?
final
contentStyle TextStyle?
final
elevation double?
final
hashCode int
The hash code for this object.
no setterinherited
headerStyle TextStyle?
final
iconSize double?
final
padding EdgeInsets?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryButtonBorderWidth double?
final
shape ShapeBorder?
final
textAlign TextAlign?
final
thumbBorder BoxBorder?
final
thumbBorderRadius BorderRadius?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited